==> ideaIC-143.747.6-sources.jar: org/jetbrains/plugins/groovy/unwrap/GroovyTryUnwrapper.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.plugins.groovy.unwrap;

import com.intellij.codeInsight.CodeInsightBundle;
import com.intellij.psi.PsiElement;
import com.intellij.util.IncorrectOperationException;
import org.jetbrains.plugins.groovy.lang.psi.api.statements.GrFinallyClause;
import org.jetbrains.plugins.groovy.lang.psi.api.statements.GrTryCatchStatement;

public class GroovyTryUnwrapper extends GroovyUnwrapper {
  public GroovyTryUnwrapper() {
    super(CodeInsightBundle.message("unwrap.try"));
  }

  @Override
  public boolean isApplicableTo(PsiElement e) {
    return e instanceof GrTryCatchStatement;
  }

  @Override
  protected void doUnwrap(final PsiElement element, final Context context) throws IncorrectOperationException {
    GrTryCatchStatement trySt = (GrTryCatchStatement)element;

    context.extractFromCodeBlock(trySt.getTryBlock(), trySt);

    GrFinallyClause finallyClause = trySt.getFinallyClause();
    if (finallyClause != null) {
      context.extractFromCodeBlock(finallyClause.getBody(), trySt);
    }

    context.delete(trySt);
  }
}

==> ideaIC-2018.3.3-sources.jar: org/jetbrains/plugins/groovy/unwrap/GroovyTryUnwrapper.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.plugins.groovy.unwrap;

import com.intellij.codeInsight.CodeInsightBundle;
import com.intellij.psi.PsiElement;
import com.intellij.util.IncorrectOperationException;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.plugins.groovy.lang.psi.api.statements.GrFinallyClause;
import org.jetbrains.plugins.groovy.lang.psi.api.statements.GrTryCatchStatement;

public class GroovyTryUnwrapper extends GroovyUnwrapper {
  public GroovyTryUnwrapper() {
    super(CodeInsightBundle.message("unwrap.try"));
  }

  @Override
  public boolean isApplicableTo(@NotNull PsiElement e) {
    return e instanceof GrTryCatchStatement;
  }

  @Override
  protected void doUnwrap(final PsiElement element, final Context context) throws IncorrectOperationException {
    GrTryCatchStatement trySt = (GrTryCatchStatement)element;

    context.extractFromCodeBlock(trySt.getTryBlock(), trySt);

    GrFinallyClause finallyClause = trySt.getFinallyClause();
    if (finallyClause != null) {
      context.extractFromCodeBlock(finallyClause.getBody(), trySt);
    }

    context.delete(trySt);
  }
}
